Module runtime

Module runtime 

SDR Runtime

Modules

buffer
Buffer Implementations for CPU and Accelerator Memory
config
Configuration Management
mocker
Mocker for unit testing and benchmarking
scheduler
Flowgraph Scheduler Trait and Implementations

Structs

BlockDescription
Description of a Block.
BlockId
Block identifier
BlockMeta
Block metadata
BlockRef
Reference to a Block that was added to the Flowgraph.
Flowgraph
The main component of any FutureSDR application.
FlowgraphDescription
Description of a Flowgraph.
FlowgraphHandle
Handle to interact with running [Flowgraph]
FlowgraphId
Port Identifier
ItemTag
Item tag
MessageOutput
Message output port
MessageOutputs
Message Outputs
PortId
Port Identifier
Runtime
The Runtime runs Flowgraphs and async tasks
RuntimeHandle
Runtime handle added as state to web handlers
WorkIo
Work IO
WrappedKernel
Typed Block

Enums

BlockMessage
Block inbox message type
BlockPortCtx
Description of the Block under which an [InvalidMessagePort] or [InvalidStreamPort] error occurred.
Error
FutureSDR Error
FlowgraphMessage
Flowgraph inbox message type
Pmt
PMT – Polymorphic Type
PmtKind
PMT types that do not wrap values.
Tag
Stream tag

Traits

Block
Block interface, implemented for WrappedKernels
Kernel
Kernal
KernelInterface
Interface to the Kernel, implemented by the block macro.

Functions

init
Initialize runtime

Type Aliases

Result
Generic Result Type used for the Kernel trait.