pub enum ReceiveError {
Closed,
SendClosed,
}Expand description
Error type for channel receive operations without timeout
Variants
Closed
Indicates that the channel is closed on both sides with a call to
close()
SendClosed
Indicates that all sender instances are dropped and the channel is closed from the send side